from django.db import models
from django.core import validators


class Item(models.Model):

    twfcheck_CHOICES = (
        (1, 'Not Yet'),
        (2, 'Confirmed'),
    )

    lwfcheck_CHOICES = (
        (1, 'Not Yet'),
        (2, 'Confirmed'),
    )

    name = models.CharField(
        verbose_name='Name',
        max_length=200,
    )

    sta = models.CharField(
        verbose_name='Station',
        max_length=200,
        blank=True,
        null=True,
    )

    net = models.CharField(
        verbose_name='Network',
        max_length=200,
        blank=True,
        null=True,
    )

    sen1sn = models.CharField(
        verbose_name='Sensor1 S/N',
        max_length=200,
        blank=True,
        null=True,
    )

    sen1model = models.CharField(
        verbose_name='Sensor1 Model',
        max_length=200,
        blank=True,
        null=True,
    )

    sen2sn = models.CharField(
        verbose_name='Sensor2 S/N',
        max_length=200,
        blank=True,
        null=True,
    )

    sen2model = models.CharField(
        verbose_name='Sensor2 Model',
        max_length=200,
        blank=True,
        null=True,
    )

    loggersn = models.CharField(
        verbose_name='Logger S/N',
        max_length=200,
        blank=True,
        null=True,
    )

    loggermodel = models.CharField(
        verbose_name='Logger Model',
        max_length=200,
        blank=True,
        null=True,
    )

    psd1z_200s = models.FloatField(
        verbose_name='Sensor1-Z PSD at 200s',
        #validators=[validators.MinValueValidator(1)],
        blank=True,
        null=True,
    )
    psd1n_200s = models.FloatField(
        verbose_name='Sensor1-N PSD at 200s',
        #validators=[validators.MinValueValidator(1)],
        blank=True,
        null=True,
    )
    psd1e_200s = models.FloatField(
        verbose_name='Sensor1-E PSD at 200s',
        #validators=[validators.MinValueValidator(1)],
        blank=True,
        null=True,
    )
    psd2z_200s = models.FloatField(
        verbose_name='Sensor2-Z PSD at 200s',
        #validators=[validators.MinValueValidator(1)],
        blank=True,
        null=True,
    )
    psd2n_200s = models.FloatField(
        verbose_name='Sensor2-N PSD at 200s',
        #validators=[validators.MinValueValidator(1)],
        blank=True,
        null=True,
    )
    psd2e_200s = models.FloatField(
        verbose_name='Sensor2-E PSD at 200s',
        #validators=[validators.MinValueValidator(1)],
        blank=True,
        null=True,
    )
    twfcheck = models.IntegerField(
        verbose_name='TeleseismicEQ Waveform Check',
        choices=twfcheck_CHOICES,
        default=1
    )

    lwfcheck = models.IntegerField(
        verbose_name='LocalEQ Waveform Check',
        choices=lwfcheck_CHOICES,
        default=1
    )


    note = models.TextField(
        verbose_name='Note',
        max_length=300,
        blank=True,
        null=True,
    )

    starting_date = models.DateTimeField(
        verbose_name='Starting Date',
        blank=True,
        null=True,
    )
    end_date = models.DateTimeField(
        verbose_name='End Date',
        blank=True,
        null=True,
    )
    created_at = models.DateTimeField(
        verbose_name='Registration Date',
        auto_now_add=True
    )

    # setting information on admin site
    def __str__(self):
        return self.name

    class Meta:
        verbose_name = 'Item'
        verbose_name_plural = 'Item'
